Menu
  * [Home](https://www.servicenow.com/blogs)
  * [Company News](https://www.servicenow.com/blogs/category/company-news)
  * [Product Insights](https://www.servicenow.com/blogs/category/product-news)
  * [Life at Now](https://www.servicenow.com/blogs/category/life-at-now)
  * [ServiceNow AI Research](https://www.servicenow.com/blogs/category/servicenow-research)
  *

# Company News
### Featured
Rule
Sidebar Featured
### Trends & Research
Rule
Sidebar Trends and Research
### Topics
### Year
We use cookies on this site to improve your browsing experience, analyze individualized usage and website traffic, tailor content to your preferences, and make your interactions with our website more meaningful. To learn more about the cookies we use and how you can change your preferences, please read our [Cookie Policy](https://www.servicenow.com/cookie-policy.html) and visit our Cookie Preference Manager. By clicking “Accept and Proceed,” closing this banner or continuing to browse this site, you consent to the use of cookies.
Accept and Proceed
![](https://id.rlcdn.com/464526.gif)![](https://pt.ispot.tv/v2/TC-8010-2.gif?app=web&type=Visit)![](https://cdn.bizible.com/ipv?_biz_r=&_biz_h=800054037&_biz_u=2cf8694a886a4b04e4addacd39b31672&_biz_l=https%3A%2F%2Fwww.servicenow.com%2Fblogs%2Fcategory%2Fcompany-news&_biz_t=1771981170026&_biz_i=Company%20News%20-%20ServiceNow%20Blog&_biz_n=4&rnd=745897&cdn_o=a&_biz_z=1771981170027)
![](https://bat.bing.com/action/0?ti=150000185&Ver=2&mid=9656b52c-eb0c-48f3-859d-9fa1209ec3b1&bo=2&sid=3d7d3e5011e511f1bb5909ea4e7c75b4&vid=3d7d5c5011e511f186802dc4edad071b&vids=0&msclkid=N&pi=918639831&lg=en-US&sw=1080&sh=600&sc=24&tl=Company%20News%20-%20ServiceNow%20Blog&p=https%3A%2F%2Fwww.servicenow.com%2Fblogs%2Fcategory%2Fcompany-news&r=&lt=1863&evt=pageLoad&sv=2&asc=G&cdb=AQAS&rn=69942)
